@@ -110,21 +110,21 @@ close(con)
 ## ----layout, echo = FALSE-----------------------------------------------------
 layout_matrix_1 <- matrix(1:4, ncol = 2)
 
-## ---- fig.cap = "The example graphs (I).", fig.height = 8, echo = FALSE-------
+## ----fig.cap = "The example graphs (I).", fig.height = 8, echo = FALSE--------
 layout(layout_matrix_1)
 plot(bf, main="a) Breath-First Search Example")
 plot(dijk, main="c) Dijkstra's Example")
 plot(df, main="b) Depth-First Search Example") 
 plot(coex, main="d) Coex Example")
 
-## ---- fig.cap = "The example graphs (II).", fig.height = 8, echo = FALSE------
+## ----fig.cap = "The example graphs (II).", fig.height = 8, echo = FALSE-------
 layout(layout_matrix_1)
 plot(coex2, main="e) Coex2 Example")
 plot(km, main="g) Kruskal MST Example")
 plot(coex2i, main="f) Coex2 Isomorphism Example")
 plot(bicoex, main="h) Biconnected Component Example")
 
-## ---- fig.cap = "The example graphs (III).", fig.height = 8, echo = FALSE-----
+## ----fig.cap = "The example graphs (III).", fig.height = 8, echo = FALSE------
 layout(layout_matrix_1)
 plot(hcs, main="k) HCS Example")
 plot(kcoex, main="m) kCores Example")
@@ -139,7 +139,7 @@ plot(FileDep)
 data(FileDep)
 FileDep
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 layout_matrix_2 <- matrix(1:2, ncol = 2)
 
 ## ----figdfsex, fig.cap = "a) The graph for depth-first-search example b) The graph for depth-first-search example, showing search orders.", echo = FALSE, results = "hide"----
@@ -296,6 +296,9 @@ tsort(FD2)
 isomorphism(dijk, coex2) 
 isomorphism(coex2i, coex2) 
 
+## ----fig.small = TRUE, fig.cap = "Example conn2i", echo = FALSE---------------
+plot(coex2i)
+
 ## ----VertexColoringdemo-------------------------------------------------------
 sequential.vertex.coloring(coex)
 
